@@ -1,15 +1,27 @@
 #![deny(future_incompatible, nonstandard_style)]
 #![warn(missing_docs, rust_2018_idioms, clippy::pedantic)]
-#![allow(clippy::needless_pass_by_value, clippy::type_complexity)]
+#![allow(
+    clippy::needless_pass_by_value,
+    clippy::type_complexity,
+    clippy::too_many_arguments
+)]
 #![cfg(any(dim2, dim3))]
 
 //! Physics behavior for Heron, using [rapier](https://rapier.rs/)
+//!
+//! # Supported custom collision shapes
+//!
+//! The following types are accepted as [`heron_core::CustomCollisionShape`]
+//! values.
+//!
+//! - [`rapier::geometry::ColliderBuilder`]
 
 #[cfg(feature = "rapier2d")]
 pub extern crate rapier2d;
 #[cfg(feature = "rapier3d")]
 pub extern crate rapier3d;
 
+use bevy::ecs::component::Component;
 use bevy::prelude::*;
 #[cfg(dim2)]
 pub(crate) use rapier2d as rapier;
@@ -20,15 +32,16 @@ use heron_core::{CollisionEvent, PhysicsSystem};
 pub use pipeline::{PhysicsWorld, RayCastInfo, ShapeCastCollisionInfo, ShapeCastCollisionType};
 
 use crate::rapier::dynamics::{
-    CCDSolver, IntegrationParameters, IslandManager, JointSet, RigidBodySet,
+    self, CCDSolver, IntegrationParameters, IslandManager, JointSet, RigidBodySet,
 };
-use crate::rapier::geometry::{BroadPhase, ColliderSet, NarrowPhase};
+use crate::rapier::geometry::{self, BroadPhase, ColliderSet, NarrowPhase};
 pub use crate::rapier::na as nalgebra;
 use crate::rapier::pipeline::{PhysicsPipeline, QueryPipeline};
 
 mod acceleration;
 mod body;
 pub mod convert;
+mod damping;
 mod pipeline;
 mod shape;
 mod velocity;
@@ -38,13 +51,27 @@ mod velocity;
 #[derive(Debug, Copy, Clone, Default)]
 pub struct RapierPlugin;
 
+/// Component that holds a reference to the rapier rigid body
+///
+/// It is automatically inserted and removed by heron.
+/// It is only useful for advanced, direct access to the rapier world
+#[derive(Debug, Copy, Clone, Eq, PartialEq, Component)]
+pub struct RigidBodyHandle(dynamics::RigidBodyHandle);
+
+/// Component that holds a reference to the rapier collider
+///
+/// It is automatically inserted and removed by heron.
+/// It is only useful for advanced, direct access to the rapier world
+#[derive(Debug, Copy, Clone, Eq, PartialEq, Component)]
+pub struct ColliderHandle(geometry::ColliderHandle);
+
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Hash, SystemLabel)]
 enum InternalSystem {
     TransformPropagation,
 }
 
 impl Plugin for RapierPlugin {
-    fn build(&self, app: &mut AppBuilder) {
+    fn build(&self, app: &mut App) {
         app.add_plugin(heron_core::CorePlugin)
             .init_resource::<PhysicsPipeline>()
             .init_resource::<body::HandleMap>()
@@ -92,6 +119,8 @@ fn update_rapier_world_stage() -> SystemStage {
         )
         .with_system(velocity::update_rapier_velocity.system())
         .with_system(acceleration::update_rapier_force_and_torque.system())
+        .with_system(damping::update_rapier_damping.system())
+        .with_system(damping::reset_rapier_damping.system())
         .with_system(shape::update_position.system())
         .with_system(shape::update_collision_groups.system())
         .with_system(shape::update_sensor_flag.system())
@@ -100,11 +129,15 @@ fn update_rapier_world_stage() -> SystemStage {
 }
 
 fn body_update_stage() -> SystemStage {
-    SystemStage::single_threaded().with_system(body::create.system())
+    SystemStage::single_threaded()
+        .with_run_criteria(heron_core::should_run.system())
+        .with_system(body::create.system())
 }
 
 fn create_collider_stage() -> SystemStage {
-    SystemStage::single_threaded().with_system(shape::create.system())
+    SystemStage::single_threaded()
+        .with_run_criteria(heron_core::should_run.system())
+        .with_system(shape::create.system())
 }
 
 fn step_systems() -> SystemSet {
